Stan Math Library: stan/math/prim/mat/fun/size.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

size.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_SIZE_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_SIZE_HPP
3
4 #include <vector>
5
6 namespace stan {
7 namespace math {
8
16 template <typename T>
17 inline int size(const std::vector<T>& x) {
18 return static_cast<int>(x.size());
19 }
20
21 }
22 }
23 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::size
int size(const std::vector< T > &x)
Return the size of the specified standard vector.
Definition: size.hpp:17

[ Stan Home Page ] © 2011–2016, Stan Development Team.